# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_lw_data_provider/lw_data_provider.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0th2_grpc_lw_data_provider/lw_data_provider.proto\x12\x14th2.data_provider.lw\x1a\x1cth2_grpc_common/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x1a\n\nEventScope\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x16\n\x06\x42ookId\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe8\x02\n\x1aMessageGroupsSearchRequest\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\x07\x62ook_id\x18\x07 \x01(\x0b\x32\x1c.th2.data_provider.lw.BookId\x12M\n\rmessage_group\x18\x03 \x03(\x0b\x32\x36.th2.data_provider.lw.MessageGroupsSearchRequest.Group\x12(\n\x04sort\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x10\n\x08raw_only\x18\x05 \x01(\x08\x12\x11\n\tkeep_open\x18\x06 \x01(\x08\x1a\x15\n\x05Group\x12\x0c\n\x04name\x18\x01 \x01(\t\"F\n\x15MessageStreamsRequest\x12-\n\x07\x62ook_id\x18\x01 \x01(\x0b\x32\x1c.th2.data_provider.lw.BookId\"\xe3\x02\n\rEventResponse\x12\x1a\n\x08\x65vent_id\x18\x01 \x01(\x0b\x32\x08.EventID\x12!\n\x0fparent_event_id\x18\x02 \x01(\x0b\x32\x08.EventID\x12\x1a\n\x08\x62\x61tch_id\x18\x03 \x01(\x0b\x32\x08.EventID\x12\x12\n\nis_batched\x18\x04 \x01(\x08\x12\x33\n\x0fstart_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x06status\x18\x07 \x01(\x0e\x32\x0c.EventStatus\x12\x12\n\nevent_name\x18\x08 \x01(\t\x12\x12\n\nevent_type\x18\t \x01(\t\x12\x0c\n\x04\x62ody\x18\n \x01(\x0c\x12\'\n\x13\x61ttached_message_id\x18\x0b \x03(\x0b\x32\n.MessageID\"<\n\x10MessageGroupItem\x12\x19\n\x07message\x18\x01 \x01(\x0b\x32\x08.Message\x12\r\n\x05match\x18\x02 \x01(\x08\"\xf7\x02\n\x14MessageGroupResponse\x12\x1e\n\nmessage_id\x18\x01 \x01(\x0b\x32\n.MessageID\x12\x31\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01\x12]\n\x12message_properties\x18\x06 \x03(\x0b\x32\x41.th2.data_provider.lw.MessageGroupResponse.MessagePropertiesEntry\x12\x10\n\x08\x62ody_raw\x18\x03 \x01(\x0c\x12#\n\x11\x61ttached_event_id\x18\x04 \x03(\x0b\x32\x08.EventID\x12<\n\x0cmessage_item\x18\x05 \x03(\x0b\x32&.th2.data_provider.lw.MessageGroupItem\x1a\x38\n\x16MessagePropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1a\n\nFilterName\x12\x0c\n\x04name\x18\x01 \x01(\t\"k\n\x06\x46ilter\x12.\n\x04name\x18\x01 \x01(\x0b\x32 .th2.data_provider.lw.FilterName\x12\x10\n\x08negative\x18\x02 \x01(\x08\x12\r\n\x05value\x18\x03 \x03(\t\x12\x10\n\x08\x63onjunct\x18\x04 \x01(\x08\"\xa1\x03\n\x12\x45ventSearchRequest\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x0cparent_event\x18\x03 \x01(\x0b\x32\x08.EventID\x12<\n\x10search_direction\x18\x04 \x01(\x0e\x32\".th2.data_provider.lw.TimeRelation\x12\x37\n\x12result_count_limit\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12,\n\x06\x66ilter\x18\x06 \x03(\x0b\x32\x1c.th2.data_provider.lw.Filter\x12-\n\x07\x62ook_id\x18\x07 \x01(\x0b\x32\x1c.th2.data_provider.lw.BookId\x12/\n\x05scope\x18\x08 \x01(\x0b\x32 .th2.data_provider.lw.EventScope\"S\n\x13\x45ventSearchResponse\x12\x34\n\x05\x65vent\x18\x01 \x01(\x0b\x32#.th2.data_provider.lw.EventResponseH\x00\x42\x06\n\x04\x64\x61ta\"\xe6\x03\n\x14MessageSearchRequest\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x10search_direction\x18\x03 \x01(\x0e\x32\".th2.data_provider.lw.TimeRelation\x12\x37\n\x12result_count_limit\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x33\n\x06stream\x18\x05 \x03(\x0b\x32#.th2.data_provider.lw.MessageStream\x12-\n\tkeep_open\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x0estream_pointer\x18\x07 \x03(\x0b\x32*.th2.data_provider.lw.MessageStreamPointer\x12\x18\n\x10response_formats\x18\x08 \x03(\t\x12-\n\x07\x62ook_id\x18\t \x01(\x0b\x32\x1c.th2.data_provider.lw.BookId\"\xae\x01\n\x15MessageSearchResponse\x12=\n\x07message\x18\x01 \x01(\x0b\x32*.th2.data_provider.lw.MessageGroupResponseH\x00\x12N\n\x17message_stream_pointers\x18\x02 \x01(\x0b\x32+.th2.data_provider.lw.MessageStreamPointersH\x00\x42\x06\n\x04\x64\x61ta\"c\n\x15MessageStreamPointers\x12J\n\x16message_stream_pointer\x18\x01 \x03(\x0b\x32*.th2.data_provider.lw.MessageStreamPointer\"p\n\x14MessageStreamPointer\x12;\n\x0emessage_stream\x18\x01 \x01(\x0b\x32#.th2.data_provider.lw.MessageStream\x12\x1b\n\x07last_id\x18\x02 \x01(\x0b\x32\n.MessageID\"<\n\rMessageStream\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\tdirection\x18\x02 \x01(\x0e\x32\n.Direction\"U\n\x16MessageStreamsResponse\x12;\n\x0emessage_stream\x18\x01 \x03(\x0b\x32#.th2.data_provider.lw.MessageStream\"\x0e\n\x0c\x42ooksRequest\"?\n\rBooksResponse\x12.\n\x08\x62ook_ids\x18\x01 \x03(\x0b\x32\x1c.th2.data_provider.lw.BookId\"\xdb\x01\n\x0fPageInfoRequest\x12-\n\x07\x62ook_id\x18\x01 \x01(\x0b\x32\x1c.th2.data_provider.lw.BookId\x12\x33\n\x0fstart_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x0cresult_limit\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\x9d\x02\n\x10PageInfoResponse\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.th2.data_provider.lw.PageId\x12-\n\x07\x63omment\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x07started\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x05\x65nded\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07updated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07removed\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"E\n\x06PageId\x12-\n\x07\x62ook_id\x18\x01 \x01(\x0b\x32\x1c.th2.data_provider.lw.BookId\x12\x0c\n\x04name\x18\x02 \x01(\t*&\n\x0cTimeRelation\x12\x08\n\x04NEXT\x10\x00\x12\x0c\n\x08PREVIOUS\x10\x01\x32\x80\x06\n\x0c\x44\x61taProvider\x12\x39\n\x08GetEvent\x12\x08.EventID\x1a#.th2.data_provider.lw.EventResponse\x12\x44\n\nGetMessage\x12\n.MessageID\x1a*.th2.data_provider.lw.MessageGroupResponse\x12n\n\x11GetMessageStreams\x12+.th2.data_provider.lw.MessageStreamsRequest\x1a,.th2.data_provider.lw.MessageStreamsResponse\x12k\n\x0eSearchMessages\x12*.th2.data_provider.lw.MessageSearchRequest\x1a+.th2.data_provider.lw.MessageSearchResponse0\x01\x12\x65\n\x0cSearchEvents\x12(.th2.data_provider.lw.EventSearchRequest\x1a).th2.data_provider.lw.EventSearchResponse0\x01\x12v\n\x13SearchMessageGroups\x12\x30.th2.data_provider.lw.MessageGroupsSearchRequest\x1a+.th2.data_provider.lw.MessageSearchResponse0\x01\x12S\n\x08GetBooks\x12\".th2.data_provider.lw.BooksRequest\x1a#.th2.data_provider.lw.BooksResponse\x12^\n\x0bGetPageInfo\x12%.th2.data_provider.lw.PageInfoRequest\x1a&.th2.data_provider.lw.PageInfoResponse0\x01\x42)\n%com.exactpro.th2.dataprovider.lw.grpcP\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'th2_grpc_lw_data_provider.lw_data_provider_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.exactpro.th2.dataprovider.lw.grpcP\001'
  _MESSAGEGROUPRESPONSE_MESSAGEPROPERTIESENTRY._options = None
  _MESSAGEGROUPRESPONSE_MESSAGEPROPERTIESENTRY._serialized_options = b'8\001'
  _MESSAGEGROUPRESPONSE.fields_by_name['timestamp']._options = None
  _MESSAGEGROUPRESPONSE.fields_by_name['timestamp']._serialized_options = b'\030\001'
  _TIMERELATION._serialized_start=3815
  _TIMERELATION._serialized_end=3853
  _EVENTSCOPE._serialized_start=196
  _EVENTSCOPE._serialized_end=222
  _BOOKID._serialized_start=224
  _BOOKID._serialized_end=246
  _MESSAGEGROUPSSEARCHREQUEST._serialized_start=249
  _MESSAGEGROUPSSEARCHREQUEST._serialized_end=609
  _MESSAGEGROUPSSEARCHREQUEST_GROUP._serialized_start=588
  _MESSAGEGROUPSSEARCHREQUEST_GROUP._serialized_end=609
  _MESSAGESTREAMSREQUEST._serialized_start=611
  _MESSAGESTREAMSREQUEST._serialized_end=681
  _EVENTRESPONSE._serialized_start=684
  _EVENTRESPONSE._serialized_end=1039
  _MESSAGEGROUPITEM._serialized_start=1041
  _MESSAGEGROUPITEM._serialized_end=1101
  _MESSAGEGROUPRESPONSE._serialized_start=1104
  _MESSAGEGROUPRESPONSE._serialized_end=1479
  _MESSAGEGROUPRESPONSE_MESSAGEPROPERTIESENTRY._serialized_start=1423
  _MESSAGEGROUPRESPONSE_MESSAGEPROPERTIESENTRY._serialized_end=1479
  _FILTERNAME._serialized_start=1481
  _FILTERNAME._serialized_end=1507
  _FILTER._serialized_start=1509
  _FILTER._serialized_end=1616
  _EVENTSEARCHREQUEST._serialized_start=1619
  _EVENTSEARCHREQUEST._serialized_end=2036
  _EVENTSEARCHRESPONSE._serialized_start=2038
  _EVENTSEARCHRESPONSE._serialized_end=2121
  _MESSAGESEARCHREQUEST._serialized_start=2124
  _MESSAGESEARCHREQUEST._serialized_end=2610
  _MESSAGESEARCHRESPONSE._serialized_start=2613
  _MESSAGESEARCHRESPONSE._serialized_end=2787
  _MESSAGESTREAMPOINTERS._serialized_start=2789
  _MESSAGESTREAMPOINTERS._serialized_end=2888
  _MESSAGESTREAMPOINTER._serialized_start=2890
  _MESSAGESTREAMPOINTER._serialized_end=3002
  _MESSAGESTREAM._serialized_start=3004
  _MESSAGESTREAM._serialized_end=3064
  _MESSAGESTREAMSRESPONSE._serialized_start=3066
  _MESSAGESTREAMSRESPONSE._serialized_end=3151
  _BOOKSREQUEST._serialized_start=3153
  _BOOKSREQUEST._serialized_end=3167
  _BOOKSRESPONSE._serialized_start=3169
  _BOOKSRESPONSE._serialized_end=3232
  _PAGEINFOREQUEST._serialized_start=3235
  _PAGEINFOREQUEST._serialized_end=3454
  _PAGEINFORESPONSE._serialized_start=3457
  _PAGEINFORESPONSE._serialized_end=3742
  _PAGEID._serialized_start=3744
  _PAGEID._serialized_end=3813
  _DATAPROVIDER._serialized_start=3856
  _DATAPROVIDER._serialized_end=4624
# @@protoc_insertion_point(module_scope)



from . import lw_data_provider_pb2_grpc as importStub

class DataProviderService(object):

    def __init__(self, router):
        self.connector = router.get_connection(DataProviderService, importStub.DataProviderStub)

    def GetEvent(self, request, timeout=None, properties=None):
        return self.connector.create_request('GetEvent', request, timeout, properties)

    def GetMessage(self, request, timeout=None, properties=None):
        return self.connector.create_request('GetMessage', request, timeout, properties)

    def GetMessageStreams(self, request, timeout=None, properties=None):
        return self.connector.create_request('GetMessageStreams', request, timeout, properties)

    def SearchMessages(self, request, timeout=None, properties=None):
        return self.connector.create_request('SearchMessages', request, timeout, properties)

    def SearchEvents(self, request, timeout=None, properties=None):
        return self.connector.create_request('SearchEvents', request, timeout, properties)

    def SearchMessageGroups(self, request, timeout=None, properties=None):
        return self.connector.create_request('SearchMessageGroups', request, timeout, properties)

    def GetBooks(self, request, timeout=None, properties=None):
        return self.connector.create_request('GetBooks', request, timeout, properties)

    def GetPageInfo(self, request, timeout=None, properties=None):
        return self.connector.create_request('GetPageInfo', request, timeout, properties)


from . import queue_data_provider_pb2_grpc as importStub

class QueueDataProviderService(object):

    def __init__(self, router):
        self.connector = router.get_connection(QueueDataProviderService, importStub.QueueDataProviderStub)

    def SearchMessageGroups(self, request, timeout=None, properties=None):
        return self.connector.create_request('SearchMessageGroups', request, timeout, properties)

    def SearchEvents(self, request, timeout=None, properties=None):
        return self.connector.create_request('SearchEvents', request, timeout, properties)